# `logbook.md`

You are responsible for keeping the `logbook.md` file in this directory **regularly updated** on the `main` branch, in accordance with the [IRP-specific academic integrity rules and expectations](https://ese-msc.github.io/irp/academic-integrity.html).

## Validating with GitHub Actions

To ensure that `logbook.md` is properly formatted and readable, make sure the `logbook` GitHub Actions workflow passes successfully.

## Inactivity Warnings

A scheduled workflow will periodically check whether `logbook.md` has been updated recently on `main`. If no recent commits are detected, a warning will be automatically raised as an issue in this repository.
